@@ -1,12 +1,11 @@
-use v5.18;
-
 package Sys::Cmd;
+use strict;
 use warnings;
+our $VERSION = '0.99.1_1';
+use 5.006;
 no warnings "experimental::lexical_subs";
 use feature 'lexical_subs';
-use Carp           ();
-use Encode::Locale ();    # Creates the 'locale' alias
-use Encode 'resolve_alias';
+use Carp ();
 use Exporter::Tidy _map => {
     run      => sub { run( undef, @_ ) },
     spawn    => sub { spawn( undef, @_ ) },
@@ -14,10 +13,7 @@ use Exporter::Tidy _map => {
     runsub   => sub { syscmd( undef, @_ )->runsub },
     spawnsub => sub { syscmd( undef, @_ )->spawnsub },
 };
-
-our $VERSION = '0.99.1';
-
-### START Class::Inline ### v0.0.1 Fri Mar 28 14:23:37 2025
+### START Class::Inline ### v0.0.1 Fri Mar 21 08:50:29 2025
 require Carp;
 our ( @_CLASS, $_FIELDS, %_NEW );
 
@@ -65,10 +61,6 @@ sub _NEW {
     $_[0]{'dir'} = eval { $_FIELDS->{'dir'}->{'isa'}->( $_[0]{'dir'} ) }
       if exists $_[0]{'dir'};
     Carp::confess( 'Sys::Cmd dir: ' . $@ ) if $@;
-    $_[0]{'encoding'} =
-      eval { $_FIELDS->{'encoding'}->{'isa'}->( $_[0]{'encoding'} ) }
-      if exists $_[0]{'encoding'};
-    Carp::confess( 'Sys::Cmd encoding: ' . $@ ) if $@;
     $_[0]{'env'} = eval { $_FIELDS->{'env'}->{'isa'}->( $_[0]{'env'} ) }
       if exists $_[0]{'env'};
     Carp::confess( 'Sys::Cmd env: ' . $@ ) if $@;
@@ -88,11 +80,7 @@ sub dir { __RO() if @_ > 1; $_[0]{'dir'} // undef }
 
 sub encoding {
     __RO() if @_ > 1;
-    $_[0]{'encoding'} //= eval {
-        $_FIELDS->{'encoding'}->{'isa'}->( $_FIELDS->{'encoding'}->{'default'} );
-    };
-    Carp::confess( 'invalid (Sys::Cmd::encoding) default: ' . $@ ) if $@;
-    $_[0]{'encoding'};
+    $_[0]{'encoding'} //= $_FIELDS->{'encoding'}->{'default'}->( $_[0] );
 }
 sub env   { __RO() if @_ > 1; $_[0]{'env'}   // undef }
 sub err   { __RO() if @_ > 1; $_[0]{'err'}   // undef }
@@ -132,7 +120,7 @@ sub _dump {
     warn "$self $x at $list[1]:$list[2]\n";
 }
 
-@_CLASS = grep 1,### END Class::Inline ###
+@_CLASS =            ### END Class::Inline ###
  {
     cmd => {
         isa => sub {
@@ -145,15 +133,8 @@ sub _dump {
         },
         required => 1,
     },
-    encoding => {
-        default => 'locale',
-        isa     => sub {
-            my $e = resolve_alias( $_[0] )
-              || _croak("Unknown Encoding: $_[0]");
-            $e;
-        },
-    },
-    env => {
+    encoding => { default => sub { ':utf8' }, },
+    env      => {
         isa => sub {
             ref $_[0] eq 'HASH' || _croak("env must be HASHREF");
             $_[0];
@@ -307,12 +288,11 @@ sub spawnsub {
 }
 
 package Sys::Cmd::Process;
-our $VERSION = '0.99.1';
+our $VERSION = '0.99.1_1';
 use parent -norequire, 'Sys::Cmd';
-use Encode 'encode';
 use IO::Handle;
 use Log::Any qw/$log/;
-### START Class::Inline ### v0.0.1 Fri Mar 28 14:23:37 2025
+### START Class::Inline ### v0.0.1 Fri Mar 21 08:50:29 2025
 require Carp;
 our ( @_CLASS, $_FIELDS, %_NEW );
 
@@ -421,7 +401,7 @@ sub _dump {
     warn "$self $x at $list[1]:$list[2]\n";
 }
 
-@_CLASS = grep 1,### END Class::Inline ###
+@_CLASS =            ### END Class::Inline ###
  {
     _coderef => {
         default => sub {
@@ -502,11 +482,6 @@ sub _spawn {
       for $old_fd0, $old_fd1, $old_fd2, $child_in, $child_out, $child_err,
       $self->stdin, $self->stdout, $self->stderr;
 
-    my $locale = $self->encoding;
-    my $cmd_as_octets =
-      [ map { encode( $locale => $_, Encode::FB_CROAK | Encode::LEAVE_SRC ) }
-          @{ $self->cmd } ];
-
     eval {
         # Re-open 0,1,2 by duping the child pipe ends
         open $fd0, '<&', fileno($child_in);
@@ -516,15 +491,14 @@ sub _spawn {
         # Kick off the new process
         $self->pid(
             Proc::FastSpawn::spawn(
-                $cmd_as_octets->[0],
-                $cmd_as_octets,
+                $self->cmd->[0],
+                $self->cmd,
                 [
                     map { $_ . '=' . ( defined $ENV{$_} ? $ENV{$_} : '' ) }
                       keys %ENV
                 ]
             )
         );
-
     };
     my $err = $@;
 
@@ -568,12 +542,12 @@ sub _fork {
     $self->exit(0);            # stop DESTROY() from trying to reap
     $child_err->autoflush(1);
 
-    my $enc = ':encoding(' . $self->encoding . ')';
+    my $enc = $self->encoding;
 
     foreach my $quad (
-        [ \*STDIN,  '<&=', fileno($child_in),  0 ],
-        [ \*STDOUT, '>&=', fileno($child_out), 1 ],
-        [ \*STDERR, '>&=', fileno($child_err), 1 ]
+        [ \*STDIN,  '<&=' . $enc, fileno($child_in),  0 ],
+        [ \*STDOUT, '>&=' . $enc, fileno($child_out), 1 ],
+        [ \*STDERR, '>&=' . $enc, fileno($child_err), 1 ]
       )
     {
         my ( $fh, $mode, $fileno, $autoflush ) = @$quad;
@@ -582,7 +556,6 @@ sub _fork {
           or print $child_err sprintf "[%d] open %s, %s: %s\n", $self->pid,
           $fh, $mode, $!;
 
-        binmode $fh, $enc;
         $fh->autoflush(1) if $autoflush;
     }
 
@@ -635,14 +608,12 @@ sub BUILD {
     local %ENV = %ENV;
 
     if ( defined( my $x = $self->env ) ) {
-        my $locale = $self->encoding;
         while ( my ( $key, $val ) = each %$x ) {
-            my $keybytes = encode( $locale, $key, Encode::FB_CROAK );
             if ( defined $val ) {
-                $ENV{$keybytes} = encode( $locale, $val, Encode::FB_CROAK );
+                $ENV{$key} = $val;
             }
             else {
-                delete $ENV{$keybytes};
+                delete $ENV{$key};
             }
         }
     }
@@ -650,7 +621,7 @@ sub BUILD {
     $self->_coderef ? $self->_fork : $self->_spawn;
     $self->stdin->autoflush(1);
 
-    my $enc = ':encoding(' . $self->encoding . ')';
+    my $enc = $self->encoding;
     binmode( $self->stdin,  $enc ) or warn "binmode stdin: $!";
     binmode( $self->stdout, $enc ) or warn "binmode stdout: $!";
     binmode( $self->stderr, $enc ) or warn "binmode stderr: $!";
@@ -662,12 +633,7 @@ sub BUILD {
         local $SIG{PIPE} =
           sub { warn "Broken pipe when writing to:" . $self->cmdline };
 
-        if ( 'ARRAY' eq ref $input && @$input ) {
-            $self->stdin->print(@$input);
-        }
-        elsif ( length $input ) {
-            $self->stdin->print($input);
-        }
+        $self->stdin->print($input) if length $input;
 
         $self->stdin->close;
     }
@@ -684,7 +650,7 @@ sub close {
         my $fh = $self->$h or next;
         $fh->opened        or next;
         if ( $h eq 'stderr' ) {
-            warn sprintf( '[%d] uncollected stderr: %s', $self->pid // -1, $_ )
+            warn sprintf( '[%d] uncollected stderr: %s', $self->pid, $_ )
               for $self->stderr->getlines;
         }
         $fh->close || Carp::carp "error closing $h: $!";
@@ -695,7 +661,8 @@ sub close {
 
 sub wait_child {
     my $self = shift;
-    my $pid  = $self->pid // return;
+
+    return unless defined $self->pid;
     return $self->exit if $self->has_exit;
 
     if ( $self->mock ) {
@@ -704,7 +671,7 @@ sub wait_child {
         $self->signal( $signal // 0 );
         $self->core( $core     // 0 );
     }
-    elsif ( $pid > 0 ) {
+    else {
 
         local $?;
         local $!;
@@ -747,13 +714,6 @@ sub wait_child {
         $self->core( $ret & 128 );
     }
 
-    # $pid <= 0, so... bad execution by spawn
-    else {
-        $self->exit(-1);
-        $self->signal(0);
-        $self->core(0);
-    }
-
     if ( $self->signal != 0 ) {
         $log->infof(
             '[%d] %s [signal: %d core: %d]',
@@ -791,7 +751,7 @@ Sys::Cmd - run a system command or spawn a system processes
 
 =head1 VERSION
 
-0.99.1 (2025-03-28)
+0.99.1_1 (2025-03-21)
 
 =head1 SYNOPSIS
 
@@ -825,7 +785,7 @@ Sys::Cmd - run a system command or spawn a system processes
     # Spawn a process for asynchronous interaction
     #  - Caller responsible for exec path, all input & output
     #  - No exception raised on non-zero exit
-    $proc = spawn( @cmd, { encoding => 'iso-8859-3' },);
+    $proc = spawn( @cmd, { encoding => ':encoding(iso-8859-3)' },);
 
     while ( my $line = $proc->stdout->getline ) {
         $proc->stdin->print("thanks\n");
@@ -885,11 +845,10 @@ following configuration keys (=> default):
 The working directory the command will be run in. Note that if C<@cmd>
 is a relative path, it may not be found from the new location.
 
-=item encoding => $Encode::Locale::ENCODING_LOCALE
+=item encoding => ':utf8'
 
-A string value identifying the encoding that applies to input/output
-file-handles, command arguments, and environment variables.  Defaults
-to the 'locale' alias from L<Encode::Locale>.
+An string value identifying the encoding of the input/output
+file-handles, passed to C<binmode>. Defaults to ':utf8'.
 
 =item env
 
@@ -899,10 +858,10 @@ from the environment altogether.
 
 =item input
 
-A scalar (string), or ARRAY reference, which is fed to the command via
-its standard input, which is then closed.  An empty value ('') or empty
-list will close the command's standard input without printing. An
-undefined value (the default) leaves the handle open.
+A string which is fed to the command via its standard input, which is
+then closed.  An empty value will close the command's standard input
+immediately. An undefined value (the default) leaves it open until the
+command terminates.
 
 Some commands close their standard input on startup, which causes a
 SIGPIPE when trying to write to it, for which B<Sys::Cmd> will warn.
@@ -1068,7 +1027,7 @@ C<spawnsub> method.
 
 =back
 
-=head1 MOCKING (EXPERIMENTAL!)
+=head1 MOCKING
 
 The C<mock> subroutine, when given, runs instead of the command line
 process. It is passed the B<Sys::Cmd::Process> object as its first
@@ -1102,9 +1061,6 @@ Those values are then returned from C<run> as usual. At present this
 feature is not useful for interactive (i.e. spawned) use, as it does
 not dynamically respond to calls to C<$proc->stdin->print()>.
 
-Note that this interface is B<EXPERIMENTAL> and subject to change!
-Don't use it anywhere you can't deal with breakage!
-
 =head1 ALTERNATIVES
 
 L<AnyEvent::Run>, L<AnyEvent::Util>, L<Argv>, L<Capture::Tiny>,
